@@ -392,6 +392,8 @@ parole_gst_draw_logo_common (ParoleGst *gst)
     gdk_window_begin_paint_region (widget->window,
 				   region);
 
+    gdk_region_destroy (region);
+
     gdk_window_clear_area (widget->window,
 			   0, 0,
 			   widget->allocation.width,
@@ -422,7 +424,7 @@ parole_gst_draw_logo_embedded (ParoleGstHelper *helper)
     
     gst = PAROLE_GST (helper);
     
-    if ( !gst->priv->terminating )
+    if ( gst->priv->terminating != TRUE )
 	parole_gst_draw_logo_common (gst);
 }
 
@@ -563,7 +565,7 @@ parole_gst_tick_timeout (gpointer data)
     gint64 pos;
     GstFormat format = GST_FORMAT_TIME;
     gint64 value;
-    gint64 video;
+    gboolean video;
     
     gst = PAROLE_GST (data);
     
@@ -910,6 +912,7 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 
     if ( gst->priv->target == new )
     {
+	gtk_widget_queue_draw (GTK_WIDGET (gst));
 	parole_gst_set_window_cursor (GTK_WIDGET (gst)->window, NULL);
 	if ( gst->priv->state_change_id != 0 )
 	    g_source_remove (gst->priv->state_change_id);
@@ -1373,7 +1376,7 @@ parole_gst_button_press_event (GtkWidget *widget, GdkEventButton *ev)
     {
 	nav = GST_NAVIGATION (gst->priv->video_sink);
 	gst_navigation_send_mouse_event (nav, "mouse-button-press", ev->button, ev->x, ev->y);
-	ret = TRUE;
+	//ret = TRUE;
     }
     
     if (GTK_WIDGET_CLASS (parole_gst_parent_class)->button_press_event)
@@ -1737,6 +1740,20 @@ parole_gst_constructed (GObject *object)
     TRACE ("End");
 }
 
+static void
+parole_gst_style_set (GtkWidget *widget, GtkStyle *prev_style)
+{
+    ParoleGst *gst;
+    
+    gst = PAROLE_GST (widget);
+    
+    if ( gst->priv->logo )
+	g_object_unref (gst->priv->logo);
+	
+    parole_gst_load_logo (gst);
+    gtk_widget_queue_draw (widget);
+}
+
 static void
 parole_gst_class_init (ParoleGstClass *klass)
 {
@@ -1755,6 +1772,7 @@ parole_gst_class_init (ParoleGstClass *klass)
     widget_class->motion_notify_event = parole_gst_motion_notify_event;
     widget_class->button_press_event = parole_gst_button_press_event;
     widget_class->button_release_event = parole_gst_button_release_event;
+    widget_class->style_set = parole_gst_style_set;
 
     signals[MEDIA_STATE] = 
         g_signal_new ("media-state",
