@@ -194,6 +194,7 @@ static GtkTargetEntry target_entry[] =
 
 struct ParolePlayerPrivate
 {
+    DBusGConnection     *bus;
     ParoleMediaList	*list;
     ParoleStatusbar     *status;
     ParoleDisc          *disc;
@@ -441,22 +442,6 @@ parole_player_media_progressed_cb (ParoleGst *gst, const ParoleStream *stream, g
     }
 }
 
-static void
-parole_player_set_playpause_widget_image (GtkWidget *widget, const gchar *stock_id)
-{
-    GtkWidget *img;
-    
-    g_object_get (G_OBJECT (widget),
-		  "image", &img,
-		  NULL);
-		  
-    g_object_set (G_OBJECT (img),
-		  "stock", stock_id,
-		  NULL);
-
-    g_object_unref (img);
-}
-
 static void
 parole_player_set_playpause_button_image (GtkWidget *widget, const gchar *stock_id)
 {
@@ -580,7 +565,8 @@ parole_player_paused (ParolePlayer *player)
     gtk_widget_set_sensitive (player->priv->play_pause, TRUE);
     gtk_widget_set_sensitive (player->priv->stop, TRUE);
     
-    parole_player_set_playpause_widget_image (player->priv->play_pause, GTK_STOCK_MEDIA_PLAY);
+    if ( player->priv->user_seeking == FALSE)
+	parole_player_set_playpause_button_image (player->priv->play_pause, GTK_STOCK_MEDIA_PLAY);
     
     if ( pix )
 	g_object_unref (pix);
@@ -624,7 +610,7 @@ parole_player_stopped (ParolePlayer *player)
     gtk_widget_set_sensitive (player->priv->seekf, FALSE);
     gtk_widget_set_sensitive (player->priv->seekb, FALSE);
 
-    parole_player_set_playpause_widget_image (player->priv->play_pause, GTK_STOCK_MEDIA_PLAY);
+    parole_player_set_playpause_button_image (player->priv->play_pause, GTK_STOCK_MEDIA_PLAY);
     
     parole_media_list_set_row_pixbuf (player->priv->list, player->priv->row, NULL);
     
@@ -1350,6 +1336,9 @@ parole_player_finalize (GObject *object)
     player = PAROLE_PLAYER (object);
 
     TRACE ("start");
+    
+    dbus_g_connection_unref (player->priv->bus);
+    
     g_object_unref (player->priv->video_filter);
     g_object_unref (player->priv->status);
     g_object_unref (player->priv->disc);
@@ -1680,6 +1669,9 @@ parole_player_init (ParolePlayer *player)
     gboolean repeat, shuffle;
     
     player->priv = PAROLE_PLAYER_GET_PRIVATE (player);
+    
+    player->priv->bus = parole_g_session_bus_get ();
+    
     player->priv->video_filter = parole_get_supported_video_filter ();
     g_object_ref_sink (player->priv->video_filter);
     
@@ -1928,7 +1920,7 @@ parole_player_dbus_class_init (ParolePlayerClass *klass)
 static void
 parole_player_dbus_init (ParolePlayer *player)
 {
-    dbus_g_connection_register_g_object (parole_g_session_bus_get (),
+    dbus_g_connection_register_g_object (player->priv->bus,
 					 PAROLE_DBUS_PATH,
 					 G_OBJECT (player));
 }
