@@ -29,6 +29,7 @@
 #include <glib.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfcegui4/libxfcegui4.h>
 
 #include <parole/parole-provider-plugin.h>
 
@@ -214,7 +215,7 @@ parole_plugins_manager_save_rc (gchar *filename, gboolean active)
 	
 	for ( i = 0; i < num; i++)
 	{
-	    if ( g_strcmp0 (saved_plugins[i], filename) )
+	    if ( g_strcmp0 (saved_plugins[i], filename) != 0 )
 		plugins_rc[i] = g_strdup (saved_plugins[i]);
 	    else
 		plugins_rc[i] = NULL;
@@ -348,6 +349,7 @@ parole_plugins_manager_get_plugin_info (const gchar *desktop_file)
 {
     ParolePluginInfo *info;
     GKeyFile *file;
+    GError *error = NULL;
     
     info = g_new0 (ParolePluginInfo, 1);
     
@@ -358,9 +360,10 @@ parole_plugins_manager_get_plugin_info (const gchar *desktop_file)
     
     file = g_key_file_new ();
     
-    if ( !g_key_file_load_from_file (file, desktop_file , G_KEY_FILE_NONE, NULL) )
+    if ( !g_key_file_load_from_file (file, desktop_file , G_KEY_FILE_NONE, &error) )
     {
-	g_warning ("Error opening file : %s", desktop_file);
+	g_warning ("Error opening file : %s : %s", desktop_file, error->message);
+	g_error_free (error);
 	goto out;
     }
     
@@ -402,6 +405,14 @@ parole_plugins_manager_show_plugins_pref (GtkWidget *widget, ParolePluginsManage
     guint i;
     
     PrefData *pref;
+    
+    /*No plugins found*/
+    if ( manager->priv->array->len == 0 )
+    {
+	xfce_info ("%s", _("No installed plugins found on this system")); 
+	return;
+    }
+    
     builder = parole_builder_new_from_string (plugins_ui, plugins_ui_length);
     
     pref = g_new0 (PrefData, 1);
@@ -526,14 +537,16 @@ static gchar *
 parole_plugins_manager_get_module_name (const gchar *desktop_file)
 {
     GKeyFile *file;
+    GError *error = NULL;
     gchar *module_name = NULL;
     gchar *library_name = NULL;
 
     file = g_key_file_new ();
     
-    if ( !g_key_file_load_from_file (file, desktop_file, G_KEY_FILE_NONE, NULL) )
+    if ( !g_key_file_load_from_file (file, desktop_file, G_KEY_FILE_NONE, &error) )
     {
-	g_warning ("Error opening file : %s", desktop_file);
+	g_warning ("Error opening file : %s : %s", desktop_file, error->message);
+	g_error_free (error);
 	goto out;
     }
     
@@ -692,7 +705,7 @@ void parole_plugins_manager_load (ParolePluginsManager *manager)
     
     if ( error )
     {
-	g_critical ("Error opening plugins data dir: %s", error->message);
+	g_debug ("No installed plugins found");
 	g_error_free (error);
 	return;
     }
@@ -707,11 +720,20 @@ void parole_plugins_manager_load (ParolePluginsManager *manager)
 	
 	if ( library_name )
 	{
-	    gchar *library_path;
 	    ParoleProviderModule *module;
+	    gchar *library_path;
+	    
 	    library_path = g_build_filename (PAROLE_PLUGINS_DIR, library_name, NULL);
+	    if ( !g_file_test (library_path, G_FILE_TEST_EXISTS) )
+	    {
+		g_debug ("Desktop file found '%s' but no plugin installed", library_path);
+		g_free (library_path);
+		continue;
+	    }
+	    TRACE ("Creating a module for %s desktop file %s", library_path, desktop_file);
 	    module = parole_provider_module_new (library_path, desktop_file);
 	    g_ptr_array_add (manager->priv->array, module);
+	    
 	    g_free (library_name);
 	    g_free (library_path);
 	}
